summaryrefslogtreecommitdiff
path: root/spec/javascripts/shortcuts_issuable_spec.js
diff options
context:
space:
mode:
authorDouwe Maan <douwe@selenight.nl>2017-01-18 16:19:51 -0600
committerDouwe Maan <douwe@selenight.nl>2017-01-18 16:19:51 -0600
commit1bf26f7aadd94e32a9cd7f78ce0b21f185f7cae3 (patch)
tree292aad931f4445e35f37517db88311db1b60120b /spec/javascripts/shortcuts_issuable_spec.js
parent3c9e556b9e1da01df0cf6527cc3468f9fed9dfeb (diff)
downloadgitlab-ce-1bf26f7aadd94e32a9cd7f78ce0b21f185f7cae3.tar.gz
Move some functions to utils
Diffstat (limited to 'spec/javascripts/shortcuts_issuable_spec.js')
-rw-r--r--spec/javascripts/shortcuts_issuable_spec.js4
1 files changed, 2 insertions, 2 deletions
diff --git a/spec/javascripts/shortcuts_issuable_spec.js b/spec/javascripts/shortcuts_issuable_spec.js
index 7e5c0e2f144..c2894d6f3ea 100644
--- a/spec/javascripts/shortcuts_issuable_spec.js
+++ b/spec/javascripts/shortcuts_issuable_spec.js
@@ -15,9 +15,9 @@
});
return describe('#replyWithSelectedText', function() {
var stubSelection;
// Stub window.gl.CopyAsGFM.getSelectedFragment to return a node with the provided HTML.
stubSelection = function(html) {
- window.gl.CopyAsGFM.getSelectedFragment = function() {
+ window.gl.utils.getSelectedFragment = function() {
var node = document.createElement('div');
node.innerHTML = html;
return node;
@@ -15,9 +15,9 @@
return describe('#replyWithSelectedText', function() {
var stubSelection;
- // Stub window.gl.CopyAsGFM.getSelectedFragment to return a node with the provided HTML.
+ // Stub window.gl.utils.getSelectedFragment to return a node with the provided HTML.
stubSelection = function(html) {